
# Type: nodeidentifier


A URI, CURIE or BNODE that represents a node in a model.

URI: [https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Nodeidentifier](https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Nodeidentifier)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **NodeIdentifier** |
| Representation | | str |
